@@ -37,7 +37,7 @@ static POOL_SESSION_CONTEXT session_context_d;
 static POOL_SESSION_CONTEXT * session_context = NULL;
 static void GetTranIsolationErrorCb(void *arg);
 static void init_sent_message_list(void);
-static POOL_PENDING_MESSAGE * copy_pending_message(POOL_PENDING_MESSAGE * messag);
+static POOL_PENDING_MESSAGE * copy_pending_message(POOL_PENDING_MESSAGE * message);
 static void dump_sent_message(char *caller, POOL_SENT_MESSAGE * m);
 static void dml_adaptive_init(void);
 static void dml_adaptive_destroy(void);
@@ -76,7 +76,7 @@ pool_init_session_context(POOL_CONNECTION * frontend, POOL_CONNECTION_POOL * bac
 	session_context->query_context = NULL;
 
 	/* Initialize local session id */
-	pool_incremnet_local_session_id();
+	pool_increment_local_session_id();
 
 	/* Create memory context */
 	/* TODO re-think about the parent for this context ?? */
@@ -171,10 +171,6 @@ pool_init_session_context(POOL_CONNECTION * frontend, POOL_CONNECTION_POOL * bac
 	dml_adaptive_init();
 
 	unset_tx_started_by_multi_statement_query();
-
-	unset_query_cache_disabled();
-
-	unset_query_cache_disabled_tx();
 }
 
 /*
@@ -1040,7 +1036,7 @@ pool_pending_messages_destroy(void)
 
 	if (!session_context)
 		ereport(ERROR,
-				(errmsg("pool_pending_message_destory: session context is not initialized")));
+				(errmsg("pool_pending_message_destroy: session context is not initialized")));
 
 	foreach(cell, session_context->pending_messages)
 	{
@@ -1094,7 +1090,7 @@ pool_pending_message_create(char kind, int len, char *contents)
 
 		default:
 			ereport(ERROR,
-					(errmsg("pool_pending_message_create: unknow kind: %c", kind)));
+					(errmsg("pool_pending_message_create: unknown kind: %c", kind)));
 			break;
 	}
 
@@ -1469,7 +1465,7 @@ const char *
 pool_pending_message_type_to_string(POOL_MESSAGE_TYPE type)
 {
 	static const char *pending_msg_string[] = {"Parse", "Bind", "Execute",
-	"Descripbe", "Close", "Sync"};
+	"Describe", "Close", "Sync"};
 
 	if (type < 0 || type > POOL_SYNC)
 		return "unknown type";
@@ -1769,7 +1765,7 @@ pool_temp_tables_destroy(void)
 {
 	if (!session_context)
 		ereport(ERROR,
-				(errmsg("pool_temp_tables_destory: session context is not initialized")));
+				(errmsg("pool_temp_tables_destroy: session context is not initialized")));
 
 	list_free(session_context->temp_tables);
 }
@@ -2015,82 +2011,3 @@ unset_tx_started_by_multi_statement_query(void)
 
 	session_context->is_tx_started_by_multi_statement = false;
 }
-
-/*
- * Set query_cache_disabled
- */
-void
-set_query_cache_disabled(void)
-{
-	if (!session_context)
-		ereport(ERROR,
-				(errmsg("set_query_cache_disabled: session context is not initialized")));
-
-	session_context->query_cache_disabled = true;
-}
-
-/*
- * Unset query_cache_disabled
- */
-void
-unset_query_cache_disabled(void)
-{
-	if (!session_context)
-		ereport(ERROR,
-				(errmsg("unset_query_cache_disabled: session context is not initialized")));
-
-	session_context->query_cache_disabled = false;
-}
-
-/*
- * Get query_cache_disabled
- */
-bool
-query_cache_disabled(void)
-{
-	if (!session_context)
-		ereport(ERROR,
-				(errmsg("query_cache_disabled: session context is not initialized")));
-
-	return session_context->query_cache_disabled ||
-		session_context->query_cache_disabled_tx;
-}
-
-/*
- * Set query_cache_disabled in transaction
- */
-void
-set_query_cache_disabled_tx(void)
-{
-	if (!session_context)
-		ereport(ERROR,
-				(errmsg("set_query_cache_disabled_tx: session context is not initialized")));
-
-	session_context->query_cache_disabled_tx = true;
-}
-
-/*
- * Unset query_cache_disabled in transaction
- */
-void
-unset_query_cache_disabled_tx(void)
-{
-	if (!session_context)
-		ereport(ERROR,
-				(errmsg("unset_query_cache_disabled_tx: session context is not initialized")));
-
-	session_context->query_cache_disabled_tx = false;
-}
-
-/*
- * Get query_cache_disabled in transaction
- */
-bool
-query_cache_disabled_tx(void)
-{
-	if (!session_context)
-		ereport(ERROR,
-				(errmsg("query_cache_disabled_tx: session context is not initialized")));
-
-	return session_context->query_cache_disabled_tx;
-}
