@@ -41,7 +41,7 @@ typedef enum
 	POOL_UNKNOWN,				/* Unknown. Need to ask backend */
 	POOL_READ_UNCOMMITTED,		/* Read uncommitted */
 	POOL_READ_COMMITTED,		/* Read committed */
-	POOL_REPEATABLE_READ,		/* Rpeatable read */
+	POOL_REPEATABLE_READ,		/* Repeatable read */
 	POOL_SERIALIZABLE			/* Serializable */
 }			POOL_TRANSACTION_ISOLATION;
 
@@ -60,8 +60,8 @@ typedef enum
  */
 typedef enum
 {
-	POOL_SENT_MESSAGE_CREATED,	/* initial state of sent meesage */
-	POOL_SENT_MESSAGE_CLOSED	/* sent meesage closed but close complete
+	POOL_SENT_MESSAGE_CREATED,	/* initial state of sent message */
+	POOL_SENT_MESSAGE_CLOSED	/* sent message closed but close complete
 								 * message has not arrived yet */
 }			POOL_SENT_MESSAGE_STATE;
 
@@ -132,7 +132,7 @@ typedef struct
 								 * kind */
 	int			contents_len;	/* message packet length */
 	char		query[QUERY_STRING_BUFFER_LEN]; /* copy of original query */
-	char		statement[MAX_IDENTIFIER_LEN];	/* prepared statment name if
+	char		statement[MAX_IDENTIFIER_LEN];	/* prepared statement name if
 												 * any */
 	char		portal[MAX_IDENTIFIER_LEN]; /* portal name if any */
 	bool		is_rows_returned;	/* true if the message could produce row
@@ -166,7 +166,6 @@ typedef enum
 	SI_SNAPSHOT_PREPARED
 } SI_STATE;
 
-
 /*
  * Per session context:
  */
@@ -259,14 +258,14 @@ typedef struct
 								 * transaction */
 
 	/*
-	 * Parse/Bind/Decribe/Execute/Close message queue.
+	 * Parse/Bind/Describe/Execute/Close message queue.
 	 */
 	List	   *pending_messages;
 
 	/*
 	 * The last pending message. Reset at Ready for query.  Note that this is
 	 * a shallow copy of pending message.  Once the are is reset,
-	 * previos_message_exists is set to false.
+	 * previous_message_exists is set to false.
 	 */
 	bool		previous_message_exists;
 	POOL_PENDING_MESSAGE previous_message;
@@ -301,7 +300,7 @@ typedef struct
 	int			preferred_main_node_id;
 #endif
 
-	/* Whether snapshot is aquired in this transaction. Only used by Snapshot Isolation mode. */
+	/* Whether snapshot is acquired in this transaction. Only used by Snapshot Isolation mode. */
 	SI_STATE	si_state;
 	/* Whether transaction is read only. Only used by Snapshot Isolation mode. */
 	SI_STATE	transaction_read_only;
@@ -310,17 +309,6 @@ typedef struct
 													 * transaction has been
 													 * started by a
 													 * multi-statement-query */
-	/*
-	 * True if query cache feature disabled until session ends.
-	 * This is set when SET ROLE/SET SESSION AUTHORIZATION executed.
-	 */
-	bool	query_cache_disabled;
-	/*
-	 * True if query cache feature disabled until current transaction ends.
-	 * This is set when REVOKE executed in a transaction.
-	 */
-	bool	query_cache_disabled_tx;
-
 }			POOL_SESSION_CONTEXT;
 
 extern void pool_init_session_context(POOL_CONNECTION * frontend, POOL_CONNECTION_POOL * backend);
@@ -408,11 +396,4 @@ extern bool is_tx_started_by_multi_statement_query(void);
 extern void set_tx_started_by_multi_statement_query(void);
 extern void unset_tx_started_by_multi_statement_query(void);
 
-extern void set_query_cache_disabled(void);
-extern void unset_query_cache_disabled(void);
-extern bool query_cache_disabled(void);
-extern void set_query_cache_disabled_tx(void);
-extern void unset_query_cache_disabled_tx(void);
-extern bool query_cache_disabled_tx(void);
-
 #endif							/* POOL_SESSION_CONTEXT_H */
