@@ -6,7 +6,7 @@
  * pgpool: a language independent connection pool server for PostgreSQL
  * written by Tatsuo Ishii
  *
- * Copyright (c) 2003-2021	PgPool Global Development Group
+ * Copyright (c) 2003-2024	PgPool Global Development Group
  *
  * Permission to use, copy, modify, and distribute this software and
  * its documentation for any purpose and without fee is hereby
@@ -527,7 +527,7 @@ typedef struct
 	bool		failover_when_quorum_exists;	/* Do failover only when wd
 												 * cluster holds the quorum */
 	bool		failover_require_consensus; /* Only do failover when majority
-											 * aggrees */
+											 * agrees */
 	bool		allow_multiple_failover_requests_from_node; /* One Pgpool-II node
 															 * can send multiple
 															 * failover requests to
@@ -546,7 +546,7 @@ typedef struct
 											/* timeout in seconds to revoke membership of
 											 * LOST watchdog nodes
 											 */
-	int 		wd_initial_node_showup_time;
+	int 		wd_no_show_node_removal_timeout;
 											/* time in seconds to revoke membership of
 											 * NO-SHOW watchdog node
 											 */
@@ -590,11 +590,12 @@ typedef struct
 	int			num_hb_dest_if;				/* number of interface devices */
 	char	  **wd_monitoring_interfaces_list;	/* network interface name list
 												 * to be monitored by watchdog */
+	bool		health_check_test;			/* if on, enable health check testing */
 
 }			POOL_CONFIG;
 
 extern POOL_CONFIG * pool_config;
-extern char *config_file_dir; /* directory path of config file pgpool.conf */
+extern char config_file_dir[]; /* directory path of config file pgpool.conf */
 
 typedef enum
 {
